@@ -339,7 +339,7 @@ int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len)
 	size = _mcrypt_get_key_sizes(len);
 	
 	ret = NULL;
-	if (size!=NULL) {
+	if (size!=NULL && (*len) != 0) {
 		ret = malloc( sizeof(int)*(*len));
 		if (ret==NULL) return NULL;
 		memcpy( ret, size, sizeof(int)*(*len));
@@ -722,7 +722,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 						int *len)
 {
 	mcrypt_dlhandle _handle;
-	int *(*_mcrypt_get_key_sizes) (int *);
+	const int *(*_mcrypt_get_key_sizes) (int *);
 	int *size;
 	int * ret_size;
 	const char* error;
@@ -745,8 +745,9 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	_mcrypt_get_key_sizes =
 	    mcrypt_dlsym(_handle, "_mcrypt_get_supported_key_sizes");
 
+	ret_size = NULL;
 	size = _mcrypt_get_key_sizes(len);
-	if (len!=0) {
+	if (*len!=0 && size!=NULL) {
 		ret_size = malloc( (*len)*sizeof(int));
 		if (ret_size!=NULL) {
 			memcpy( ret_size, size, (*len)*sizeof(int));
