@@ -19,10 +19,11 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rijndael-256.c,v 1.9 2001/05/17 19:09:08 nmav Exp $ */
+/* $Id: rijndael-256.c,v 1.12 2001/09/09 09:52:55 nmav Exp $ */
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+
+#include <mcrypt_modules.h>
 #include "rijndael.h"
 
 #ifdef USE_LTDL
@@ -422,21 +423,17 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 {
 	return 32;
 }
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+
+static const int key_sizes[] = { 16, 24, 32 };
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(3 * sizeof(int));
-	size[0] = 16;
-	size[1] = 24;
-	size[2] = 32;
-	*len = 3;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
+
 }
 WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(14);
-	strcpy(x, "Rijndael-256");
-	return x;
+return "Rijndael-256";
 }
 
 #define CIPHER "45af6c269326fd935edd24733cff74fc1aa358841a6cd80b79f242d983f8ff2e"
@@ -498,5 +495,5 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 
 WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
-	return 19991129;
+	return 20010801;
 }
